==> uicilibris_1.4.orig.tar.gz: uicilibris-1.4.orig/uicilibris/lang/uicilibris_en_US.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../uicilibris.ui" line="14"/>
        <source>UICI LIBRIS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="32"/>
        <source>Drop area</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="35"/>
        <source>this tab is for Wiki code.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="38"/>
        <source>this tab is for Wiki code. It accepts pasting, and also drag/drops.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="46"/>
        <source>you can select a part of the code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="49"/>
        <source>When a selection is done, the conversion to LaTeX is done with that selection only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="147"/>
        <source>Actions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="104"/>
        <source>Converts the selected wikicode to LaTeX</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="107"/>
        <source>&amp;Text to LaTeX</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="91"/>
        <source>Converts the selected wikilinks to LaTeX</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="94"/>
        <source>&amp;Links to LaTeX</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="62"/>
        <source>Click here to edit the base address of the mediawiki</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="65"/>
        <source>Click &apos;Base MediaWiki&apos;s address&apos; to edit the base address of the mediawiki</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="68"/>
        <source>Base MediaWiki&apos;s address</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="81"/>
        <source>...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="120"/>
        <source>Latex code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="123"/>
        <source>This tab is for LaTeX code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="126"/>
        <source>The LaTeX code in this tab will be compiled with pdflatex upon request.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="137"/>
        <source>modification is possible</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="140"/>
        <source>modification is possible prior to running pdflatex</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="153"/>
        <source>Click here to begin a compilation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="156"/>
        <source>Click &apos;Run PdfLatex&apos; to begin a compilation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="159"/>
        <source>&amp;Run PdfLatex</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="166"/>
        <source>Click here to view the generated PDF file when available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="169"/>
        <source>Click &apos;View PDF&apos; to view the generated PDF file when available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="172"/>
        <source>&amp;View PDF</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="182"/>
        <source>Opens a Terminal to hack the source in a temporary environment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="185"/>
        <source>Hack LaTeX source</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="192"/>
        <source>Click here to browse the log file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="195"/>
        <source>Click here to browse the log file output by pdflatex</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="198"/>
        <source>Browse logs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="211"/>
        <source>Latex Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="214"/>
        <source>This tab displays the log file output by pdflatex</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="217"/>
        <source>After a run of pdftlatex, errors and warnings emitted during the compilation can be searched in this tab.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="232"/>
        <source>Find</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="250"/>
        <source>Type a string (or select it in a list) to search it</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="253"/>
        <source>Type a string in the combo box (or select it in the combo&apos;s list) to search it</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="263"/>
        <source>Click here to find the next occurence of the searched string</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="266"/>
        <source>Click &apos;Next&apos; to find the next occurence of the searched string</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="269"/>
        <source>Next</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="282"/>
        <source>Errors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="285"/>
        <source>This tab is for errors raised by Uicilibris</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="288"/>
        <source>Uicilibris can detect a few errors. They are reported in this tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="318"/>
        <source>&amp;File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="328"/>
        <source>&amp;Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="339"/>
        <source>&amp;Quit (Ctrl-Q)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="342"/>
        <source>Ctrl+Q</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="347"/>
        <source>&amp;About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="352"/>
        <source>User &amp;manual</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="355"/>
        <source>F1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>uicilibris</name>
    <message>
        <location filename="../uicilibris" line="159"/>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris" line="208"/>
        <source>Expanding to LaTeX</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris" line="238"/>
        <source>Connection to %1 ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris" line="334"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris" line="241"/>
        <source>Links to LaTeX processing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris" line="272"/>
        <source>processing &apos;%1&apos; ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris" line="312"/>
        <source>Pdflatex failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris" line="312"/>
        <source>For some reason, Pdflatex failed.&lt;b /&gt;Try to hack around.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris" line="334"/>
        <source>Getting images ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris" line="336"/>
        <source>LaTeX compilation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris" line="349"/>
        <source>getting &apos;%1&apos; ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris" line="367"/>
        <source>Cannot open PDF file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris" line="367"/>
        <source>There is no reachable PDF file. Compile the LaTeX source, or check the error tab.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris" line="379"/>
        <source>Cannot find the temporary files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris" line="379"/>
        <source>There is no temporary files. Please run Pdflatex.</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../__init__.py" line="159"/>
        <source>À propos</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> uicilibris_1.6.orig.tar.gz: uicilibris-1.6.orig/uicilibris/lang/uicilibris_en_US.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../uicilibris.ui" line="14"/>
        <source>UICI LIBRIS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="32"/>
        <source>Drop area</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="35"/>
        <source>this tab is for Wiki code.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="38"/>
        <source>this tab is for Wiki code. It accepts pasting, and also drag/drops.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="46"/>
        <source>you can select a part of the code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="49"/>
        <source>When a selection is done, the conversion to LaTeX is done with that selection only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="181"/>
        <source>Actions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="82"/>
        <source>Converts the selected wikicode to LaTeX</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="85"/>
        <source>&amp;Text to LaTeX</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="69"/>
        <source>Converts the selected wikilinks to LaTeX</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="72"/>
        <source>&amp;Links to LaTeX</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="108"/>
        <source>Click here to edit the base address of the mediawiki</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="111"/>
        <source>Click &apos;Base MediaWiki&apos;s address&apos; to edit the base address of the mediawiki</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="127"/>
        <source>...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="154"/>
        <source>Latex code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="157"/>
        <source>This tab is for LaTeX code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="160"/>
        <source>The LaTeX code in this tab will be compiled with pdflatex upon request.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="171"/>
        <source>modification is possible</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="174"/>
        <source>modification is possible prior to running pdflatex</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="187"/>
        <source>Click here to begin a compilation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="190"/>
        <source>Click &apos;Run PdfLatex&apos; to begin a compilation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="193"/>
        <source>&amp;Run PdfLatex</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="200"/>
        <source>Click here to view the generated PDF file when available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="203"/>
        <source>Click &apos;View PDF&apos; to view the generated PDF file when available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="206"/>
        <source>&amp;View PDF</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="216"/>
        <source>Opens a Terminal to hack the source in a temporary environment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="219"/>
        <source>Hack LaTeX source</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="226"/>
        <source>Click here to browse the log file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="229"/>
        <source>Click here to browse the log file output by pdflatex</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="232"/>
        <source>Browse logs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="245"/>
        <source>Latex Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="248"/>
        <source>This tab displays the log file output by pdflatex</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="251"/>
        <source>After a run of pdftlatex, errors and warnings emitted during the compilation can be searched in this tab.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="266"/>
        <source>Find</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="284"/>
        <source>Type a string (or select it in a list) to search it</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="287"/>
        <source>Type a string in the combo box (or select it in the combo&apos;s list) to search it</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="297"/>
        <source>Click here to find the next occurence of the searched string</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="300"/>
        <source>Click &apos;Next&apos; to find the next occurence of the searched string</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="303"/>
        <source>Next</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="316"/>
        <source>Errors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="319"/>
        <source>This tab is for errors raised by Uicilibris</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="322"/>
        <source>Uicilibris can detect a few errors. They are reported in this tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="352"/>
        <source>&amp;File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="362"/>
        <source>&amp;Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="373"/>
        <source>&amp;Quit (Ctrl-Q)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="376"/>
        <source>Ctrl+Q</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="381"/>
        <source>&amp;About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="386"/>
        <source>User &amp;manual</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="389"/>
        <source>F1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="114"/>
        <source>Base</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>uicilibris</name>
    <message>
        <location filename="../uicilibris" line="208"/>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris" line="254"/>
        <source>Expanding to LaTeX</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris" line="397"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris" line="282"/>
        <source>Links to LaTeX processing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris" line="330"/>
        <source>processing &apos;%1&apos; ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris" line="375"/>
        <source>Pdflatex failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris" line="375"/>
        <source>For some reason, Pdflatex failed.&lt;b /&gt;Try to hack around.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris" line="397"/>
        <source>Getting images ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris" line="399"/>
        <source>LaTeX compilation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris" line="412"/>
        <source>getting &apos;%1&apos; ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris" line="430"/>
        <source>Cannot open PDF file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris" line="430"/>
        <source>There is no reachable PDF file. Compile the LaTeX source, or check the error tab.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris" line="442"/>
        <source>Cannot find the temporary files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris" line="442"/>
        <source>There is no temporary files. Please run Pdflatex.</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../__init__.py" line="159"/>
        <source>À propos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris" line="90"/>
        <source>Style = Wiki to Book</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris" line="91"/>
        <source>Style = Wiki to Article</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris" line="92"/>
        <source>Style = Wiki to Beamer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris" line="279"/>
        <source>Connection to the mediawiki ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris" line="343"/>
        <source>Feature not yet implemented</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris" line="343"/>
        <source>The feature &apos;%1&apos; is not yet implemented. Report a bug to the developers.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
